import { SendServerMessage } from 'common-ts/index.js';
import { getMessageBody } from 'common-ts/util/message-util.js';
import { validateBoolean, validateNumber, validateString } from 'common-ts/util/validation-util.js';
// Expose all 'common' endpoints
export * from 'common-ts/index.js';
/** Blockchain functions */
export function GetBlockCount() {
    console.debug('GetBlockCount()');
    const m = getMessageBody("getblockcount" /* getblockcount */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetFilterCount() {
    console.debug('GetFilterCount()');
    const m = getMessageBody("getfiltercount" /* getfiltercount */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetFilterHeaderCount() {
    console.debug('GetFilterHeaderCount()');
    const m = getMessageBody("getfilterheadercount" /* getfilterheadercount */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
// returns "failure" for not found, needs error wrapped
export function GetBlockHeader(sha256hash) {
    console.debug('GetBlockHeader()', sha256hash);
    validateString(sha256hash, 'GetBlockHeader()', 'sha256hash');
    const m = getMessageBody("getblockheader" /* getblockheader */, [sha256hash]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetInfo() {
    console.debug('GetInfo()');
    const m = getMessageBody("getinfo" /* getinfo */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
/** Network message functions */
export function GetPeers() {
    console.debug('GetPeers()');
    const m = getMessageBody("getpeers" /* getpeers */);
    return SendServerMessage(m).then(response => {
        // Current response: 'TODO implement getpeers'
        return response;
    });
}
export function Stop() {
    console.debug('Stop()');
    const m = getMessageBody("stop" /* stop */);
    return SendServerMessage(m).then(response => {
        // Current response: 'Node shutting down'
        return response;
    });
}
// export function DecodeRawTransaction() {
//   console.debug('GetFilterHeaderCount()')
//   const m = getMessageBody(BlockchainMessageType.decoderawtransaction)
//   return SendOracleMessage(m).then(response => {
//     return <ServerResponse<VersionResponse>>response
//   })
// }
/** Specific Server message functions */
export function IsEmpty() {
    console.debug('IsEmpty()');
    const m = getMessageBody("isempty" /* isempty */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function WalletInfo() {
    console.debug('WalletInfo()');
    const m = getMessageBody("walletinfo" /* walletinfo */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
// Do we want this to just return a number vs string with label?
export function GetBalance(inSats) {
    console.debug('GetBalance()', inSats);
    validateBoolean(inSats, 'GetBalance()', 'inSats');
    const m = getMessageBody("getbalance" /* getbalance */, [inSats]);
    return SendServerMessage(m).then(response => {
        // This comes with ' sats' or ' BTC' label
        return response;
    });
}
// Do we want this to just return a number vs string with label?
export function GetConfirmedBalance(inSats) {
    console.debug('GetConfirmedBalance()', inSats);
    validateBoolean(inSats, 'GetConfirmedBalance()', 'inSats');
    const m = getMessageBody("getconfirmedbalance" /* getconfirmedbalance */, [inSats]);
    return SendServerMessage(m).then(response => {
        // This comes with ' sats' or ' BTC' label
        return response;
    });
}
// Do we want this to just return a number vs string with label?
export function GetUnconfirmedBalance(inSats) {
    console.debug('GetUnconfirmedBalance()', inSats);
    validateBoolean(inSats, 'GetUnconfirmedBalance()', 'inSats');
    const m = getMessageBody("getunconfirmedbalance" /* getunconfirmedbalance */, [inSats]);
    return SendServerMessage(m).then(response => {
        // This comes with ' sats' or ' BTC' label
        return response;
    });
}
export function GetBalances(inSats) {
    console.debug('GetBalances()', inSats);
    validateBoolean(inSats, 'GetBalances()', 'inSats');
    const m = getMessageBody("getbalances" /* getbalances */, [inSats]);
    return SendServerMessage(m).then(response => {
        // This comes with ' sats' or ' BTC' label
        return response;
    });
}
// Should it be possible to create a new address without a label?
export function GetNewAddress(label) {
    console.debug('GetNewAddress()', label);
    if (label !== undefined) {
        validateString(label, 'GetNewAddress()', 'label');
        const m = getMessageBody("getnewaddress" /* getnewaddress */, [label]);
        return SendServerMessage(m).then(response => {
            return response;
        });
    }
    else {
        const m = getMessageBody("getnewaddress" /* getnewaddress */);
        return SendServerMessage(m).then(response => {
            return response;
        });
    }
}
export function GetTransaction(sha256hash) {
    console.debug('GetTransaction()', sha256hash);
    validateString(sha256hash, 'GetTransaction()', 'sha256hash');
    const m = getMessageBody("gettransaction" /* gettransaction */, [sha256hash]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function LockUnspent(unlock, outPoints) {
    console.debug('LockUnspent()', unlock, outPoints);
    validateBoolean(unlock, 'LockUnspent()', 'unlock');
    // validateString(outPoints, 'LockUnspent()', 'outPoints')
    const m = getMessageBody("lockunspent" /* lockunspent */, [unlock, outPoints]);
    return SendServerMessage(m).then(response => {
        // boolean value === ?
        return response;
    });
}
export function LabelAddress(address, label) {
    console.debug('LabelAddress()', address, label);
    validateString(address, 'LabelAddress()', 'address');
    validateString(label, 'LabelAddress()', 'label');
    const m = getMessageBody("labeladdress" /* labeladdress */, [address, label]);
    return SendServerMessage(m).then(response => {
        // response like "Added label 'test label' to tb1qd8ap8lrzvvgw3k3wjfxcxsgz4wtspxysrs7a05",
        return response;
    });
}
export function DropAddressLabel(address, label) {
    console.debug('DropAddressLabel()', address, label);
    validateString(address, 'DropAddressLabel()', 'address');
    validateString(label, 'DropAddressLabel()', 'label');
    const m = getMessageBody("dropaddresslabel" /* dropaddresslabel */, [address, label]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetAddressLabels() {
    console.debug('GetAddressLabels()');
    const m = getMessageBody("getaddresslabels" /* getaddresslabels */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function DropAddressLabels(address) {
    console.debug('DropAddressLabels()', address);
    validateString(address, 'DropAddressLabels()', 'address');
    const m = getMessageBody("dropaddresslabels" /* dropaddresslabels */, [address]);
    return SendServerMessage(m).then(response => {
        // response like '1 label dropped'
        return response;
    });
}
/** DLC Message Functions */
export function GetDLCHostAddress() {
    console.debug('GetDLCHostAddress()');
    const m = getMessageBody("getdlchostaddress" /* getdlchostaddress */);
    return SendServerMessage(m).then(response => {
        // response like '0:0:0:0:0:0:0:0:2862'
        return response;
    });
}
// payoutsVal: ContractDescriptorV0TLV / tlvPoints
export function CreateContractInfo(announcementTLV, totalCollateral, payoutsVal) {
    console.debug('CreateContractInfo()');
    const m = getMessageBody("createcontractinfo" /* createcontractinfo */, [announcementTLV, totalCollateral, payoutsVal]);
    return SendServerMessage(m).then(response => {
        // on fail returns "failure"
        return response;
    });
}
export function GetDLCs(contactAddress) {
    console.debug('GetDLCs()');
    let params = undefined;
    if (contactAddress) {
        params = [contactAddress];
    }
    const m = getMessageBody("getdlcs" /* getdlcs */, params);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetDLC(sha256hash) {
    console.debug('GetDLC()', sha256hash);
    const m = getMessageBody("getdlc" /* getdlc */, [sha256hash]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function CancelDLC(sha256hash) {
    console.debug('CancelDLC()', sha256hash);
    const m = getMessageBody("canceldlc" /* canceldlc */, [sha256hash]);
    return SendServerMessage(m).then(response => {
        // result like 'Success'
        return response;
    });
}
// ContractInfoV0TLV
// collateral in sats
// feeRate in sats / vbyte
export function CreateDLCOffer(contractInfoTLV, collateral, feeRate, locktime, refundLT) {
    console.debug('CreateDLCOffer()', contractInfoTLV, collateral, feeRate, locktime, refundLT);
    validateString(contractInfoTLV, 'CreateDLCOffer()', 'contractInfoTLV');
    validateNumber(collateral, 'CreateDLCOffer()', 'collateral');
    validateNumber(feeRate, 'CreateDLCOffer()', 'feeRate');
    validateNumber(locktime, 'CreateDLCOffer()', 'locktime');
    validateNumber(refundLT, 'CreateDLCOffer()', 'refundLT');
    const m = getMessageBody("createdlcoffer" /* createdlcoffer */, [contractInfoTLV, collateral, feeRate, locktime, refundLT]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetDLCOffer(temporaryContractId) {
    console.debug('GetDLCOffer()', temporaryContractId);
    validateString(temporaryContractId, 'GetDLCOffer()', 'temporaryContractId');
    const m = getMessageBody("getdlcoffer" /* getdlcoffer */, [temporaryContractId]);
    return SendServerMessage(m).then(response => {
        // response is DLC offer message in hex
        return response;
    });
}
export function AcceptDLCOffer(offerHex) {
    console.debug('AcceptDLCOffer()', offerHex);
    validateString(offerHex, 'AcceptDLCOffer()', 'offerHex');
    // Flexing via UI...
    //       2021-11-22T19:09:37.173Z error: onError socket hang up
    // [HPM] Error occurred while proxying request localhost:4200 to http://localhost:9999/ [ECONNRESET] (https://nodejs.org/api/errors.html#errors_common_system_errors)
    const m = getMessageBody("acceptdlcoffer" /* acceptdlcoffer */, [offerHex]);
    return SendServerMessage(m).then(response => {
        // response is DLC accept message in hex
        // example numeric amount size is 86k
        return response;
    });
}
export function AcceptDLCOfferFromFile(path, destination) {
    console.debug('AcceptDLCOfferFromFile()', path, destination);
    validateString(path, 'AcceptDLCOfferFromFile()', 'path');
    if (destination !== undefined)
        validateString(destination, 'AcceptDLCOfferFromFile()', 'destination');
    const args = [path];
    if (destination !== undefined)
        args.push(destination);
    const m = getMessageBody("acceptdlcofferfromfile" /* acceptdlcofferfromfile */, args);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function SignDLC(acceptHex) {
    console.debug('SignDLC()', acceptHex);
    validateString(acceptHex, 'SignDLC()', 'acceptHex');
    const m = getMessageBody("signdlc" /* signdlc */, [acceptHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function SignDLCFromFile(path, destination) {
    console.debug('SignDLCFromFile()', path, destination);
    validateString(path, 'SignDLCFromFile()', 'path');
    if (destination !== undefined)
        validateString(destination, 'SignDLCFromFile()', 'destination');
    const args = [path];
    if (destination !== undefined)
        args.push(destination);
    const m = getMessageBody("signdlcfromfile" /* signdlcfromfile */, args);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function AddDLCSigs(sigsHex) {
    console.debug('AddDLCSigs()', sigsHex);
    validateString(sigsHex, 'AddDLCSigs()', 'sigsHex');
    const m = getMessageBody("adddlcsigs" /* adddlcsigs */, [sigsHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function AddDLCSigsFromFile(path, destination) {
    console.debug('AddDLCSigsFromFile()', path, destination);
    validateString(path, 'AddDLCSigsFromFile()', 'path');
    if (destination !== undefined)
        validateString(destination, 'AddDLCSigsFromFile()', 'destination');
    const args = [path];
    if (destination !== undefined)
        args.push(destination);
    const m = getMessageBody("adddlcsigsfromfile" /* adddlcsigsfromfile */, args);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function AddDLCSigsAndBroadcast(sigsHex) {
    console.debug('AddDLCSigsAndBroadcast()', sigsHex);
    validateString(sigsHex, 'AddDLCSigsAndBroadcast()', 'sigsHex');
    const m = getMessageBody("adddlcsigsandbroadcast" /* adddlcsigsandbroadcast */, [sigsHex]);
    return SendServerMessage(m).then(response => {
        // Return is txId
        return response;
    });
}
export function AddDLCSigsAndBroadcastFromFile(path, destination) {
    console.debug('AddDLCSigsAndBroadcastFromFile()', path, destination);
    validateString(path, 'AddDLCSigsAndBroadcastFromFile()', 'path');
    if (destination !== undefined)
        validateString(destination, 'AddDLCSigsAndBroadcastFromFile()', 'destination');
    const args = [path];
    if (destination !== undefined)
        args.push(destination);
    const m = getMessageBody("adddlcsigsandbroadcastfromfile" /* adddlcsigsandbroadcastfromfile */, args);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetDLCFundingTx(contractIdHex) {
    console.debug('GetDLCFundingTx()', contractIdHex);
    validateString(contractIdHex, 'GetDLCFundingTx()', 'contractIdHex');
    const m = getMessageBody("getdlcfundingtx" /* getdlcfundingtx */, [contractIdHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function BroadcastDLCFundingTx(contractIdHex) {
    console.debug('BroadcastDLCFundingTx()', contractIdHex);
    validateString(contractIdHex, 'GetDLCFundingTx()', 'contractIdHex');
    const m = getMessageBody("broadcastdlcfundingtx" /* broadcastdlcfundingtx */, [contractIdHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function ExecuteDLC(contractIdHex, oracleSigs, noBroadcast) {
    console.debug('ExecuteDLC()', contractIdHex, oracleSigs, noBroadcast);
    validateString(contractIdHex, 'ExecuteDLC()', 'contractIdHex');
    // TODO : Validate oracleSigs
    validateBoolean(noBroadcast, 'ExecuteDLC()', 'noBroadcast');
    const m = getMessageBody("executedlc" /* executedlc */, [contractIdHex, oracleSigs, noBroadcast]);
    return SendServerMessage(m).then(response => {
        // Return is closing txId
        return response;
    });
}
export function ExecuteDLCRefund(contractIdHex, noBroadcast) {
    console.debug('ExecuteDLCRefund()', contractIdHex);
    validateString(contractIdHex, 'ExecuteDLC()', 'contractIdHex');
    validateBoolean(noBroadcast, 'ExecuteDLC()', 'noBroadcast');
    const m = getMessageBody("executedlcrefund" /* executedlcrefund */, [contractIdHex, noBroadcast]);
    return SendServerMessage(m).then(response => {
        // Return is txId
        return response;
    });
}
export function SendToAddress(address, bitcoins, satsPerVByte, noBroadcast) {
    console.debug('SendToAddress()', address, bitcoins, satsPerVByte, noBroadcast);
    validateString(address, 'SendToAddress()', 'address');
    validateNumber(bitcoins, 'SendToAddress()', 'bitcoins');
    validateNumber(satsPerVByte, 'SendToAddress()', 'satsPerVByte');
    validateBoolean(noBroadcast, 'SendToAddress()', 'noBroadcast');
    const m = getMessageBody("sendtoaddress" /* sendtoaddress */, [address, bitcoins, satsPerVByte, noBroadcast]);
    return SendServerMessage(m).then(response => {
        // Return is txId
        return response;
    });
}
export function SendFromOutpoints(outPoints, bitcoins, satsPerVByte) {
    console.debug('SendFromOutpoints()', outPoints, bitcoins, satsPerVByte);
    // TODO : Validate outPoints[]
    validateNumber(bitcoins, 'SendFromOutpoints()', 'bitcoins');
    validateNumber(satsPerVByte, 'SendFromOutpoints()', 'satsPerVByte');
    const m = getMessageBody("sendfromoutpoints" /* sendfromoutpoints */, [outPoints, bitcoins, satsPerVByte]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function SweepWallet(address, satsPerVByte) {
    console.debug('SweepWallet()', address, satsPerVByte);
    validateString(address, 'SweepWallet()', 'address');
    validateNumber(satsPerVByte, 'SweepWallet()', 'satsPerVByte');
    const m = getMessageBody("dropaddresslabels" /* dropaddresslabels */, [address]);
    return SendServerMessage(m).then(response => {
        // Return is txId
        return response;
    });
}
export function SendWithAlgo(address, bitcoins, satsPerVByte, algo) {
    console.debug('SendWithAlgo()', address, bitcoins, satsPerVByte, algo);
    validateString(address, 'SendWithAlgo()', 'address');
    validateNumber(bitcoins, 'SendWithAlgo()', 'bitcoins');
    validateNumber(satsPerVByte, 'SendWithAlgo()', 'satsPerVByte');
    validateString(algo, 'SendWithAlgo()', 'algo');
    const m = getMessageBody("sendwithalgo" /* sendwithalgo */, [address, bitcoins, satsPerVByte, algo]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function SignPSBT(hexOrBase64) {
    console.debug('SignPSBT()', hexOrBase64);
    validateString(hexOrBase64, 'SignPSBT()', 'hexOrBase64');
    const m = getMessageBody("signpsbt" /* signpsbt */, [hexOrBase64]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function OpReturnCommit(message, hashMessage, satsPerVByte) {
    console.debug('OpReturnCommit()', message, hashMessage, satsPerVByte);
    validateString(message, 'OpReturnCommit()', 'message');
    validateBoolean(hashMessage, 'OpReturnCommit()', 'hashMessage');
    validateNumber(satsPerVByte, 'OpReturnCommit()', 'satsPerVByte');
    const m = getMessageBody("opreturncommit" /* opreturncommit */, [message, hashMessage, satsPerVByte]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function BumpFeeRBF(sha256hash, satsPerVByte) {
    console.debug('BumpFeeRBF()', sha256hash, satsPerVByte);
    validateString(sha256hash, 'BumpFeeRBF()', 'sha256hash');
    validateNumber(satsPerVByte, 'BumpFeeRBF()', 'satsPerVByte');
    const m = getMessageBody("bumpfeerbf" /* bumpfeerbf */, [sha256hash, satsPerVByte]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function BumpFeeCPFP(sha256hash, satsPerVByte) {
    console.debug('BumpFeeCPFP()', sha256hash, satsPerVByte);
    validateString(sha256hash, 'BumpFeeCPFP()', 'sha256hash');
    validateNumber(satsPerVByte, 'BumpFeeCPFP()', 'satsPerVByte');
    const m = getMessageBody("bumpfeecpfp" /* bumpfeecpfp */, [sha256hash, satsPerVByte]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function Rescan(batchSize, start, end, force, ignoreCreationTime) {
    console.debug('Rescan()', batchSize, start, end, force, ignoreCreationTime);
    if (batchSize !== null)
        validateNumber(batchSize, 'Rescan()', 'batchSize');
    if (start !== null)
        validateNumber(start, 'Rescan()', 'start');
    if (end !== null)
        validateNumber(end, 'Rescan()', 'end');
    validateBoolean(force, 'Rescan()', 'force');
    validateBoolean(ignoreCreationTime, 'Rescan()', 'ignoreCreationTime');
    const m = getMessageBody("rescan" /* rescan */, [batchSize, start, end, force, ignoreCreationTime]);
    return SendServerMessage(m).then(response => {
        // result like "Rescan started."
        return response;
    });
}
export function GetUTXOs() {
    console.debug('GetUTXOs()');
    const m = getMessageBody("getutxos" /* getutxos */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function ListReservedUTXOs() {
    console.debug('ListReservedUTXOs()');
    const m = getMessageBody("listreservedutxos" /* listreservedutxos */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetAddresses() {
    console.debug('GetAddresses()');
    const m = getMessageBody("getaddresses" /* getaddresses */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetSpentAddresses() {
    console.debug('GetSpentAddresses()');
    const m = getMessageBody("getspentaddresses" /* getspentaddresses */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetFundedAddresses() {
    console.debug('GetFundedAddresses()');
    const m = getMessageBody("getfundedaddresses" /* getfundedaddresses */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetUnusedAddresses() {
    console.debug('GetUnusedAddresses()');
    const m = getMessageBody("getunusedaddresses" /* getunusedaddresses */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function GetAccounts() {
    console.debug('GetAccounts()');
    const m = getMessageBody("getaccounts" /* getaccounts */);
    return SendServerMessage(m).then(response => {
        // response like ['tpub...','vpub...','upub...']
        return response;
    });
}
export function GetAddressInfo(address) {
    console.debug('GetAddressInfo()', address);
    const m = getMessageBody("getaddressinfo" /* getaddressinfo */, [address]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
// THIS IS UNTESTED
export function CreateNewAccount() {
    console.debug('CreateNewAccount()');
    const m = getMessageBody("createnewaccount" /* createnewaccount */);
    return SendServerMessage(m).then(response => {
        // response like 
        return response;
    });
}
// keymanagerpassphrasechange
// keymanagerpassphraseset
export function ImportSeed(walletName, mnemonic, passphrase) {
    console.debug('ImportSeed()', walletName); // not logging mnemonic, passphrase
    validateString(walletName, 'ImportSeed()', 'walletName');
    validateString(mnemonic, 'ImportSeed()', 'mnemonic');
    if (passphrase !== undefined)
        validateString(passphrase, 'ImportSeed()', 'passphrase');
    const m = getMessageBody("importseed" /* importseed */, [walletName, mnemonic, passphrase]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function ImportXprv(walletName, mnemonic, passphrase) {
    console.debug('ImportXprv()', walletName); // not logging mnemonic, passphrase
    validateString(walletName, 'ImportXprv()', 'walletName');
    validateString(mnemonic, 'ImportXprv()', 'mnemonic');
    if (passphrase !== undefined)
        validateString(passphrase, 'ImportXprv()', 'passphrase');
    const m = getMessageBody("importxprv" /* importxprv */, [walletName, mnemonic, passphrase]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function SendRawTransaction(hex) {
    console.debug('SendRawTransaction()', hex);
    validateString(hex, 'SendRawTransaction()', 'hex');
    const m = getMessageBody("sendrawtransaction" /* sendrawtransaction */, [hex]);
    return SendServerMessage(m).then(response => {
        // Returns txId
        return response;
    });
}
export function EstimateFee() {
    console.debug('EstimateFee()');
    const m = getMessageBody("estimatefee" /* estimatefee */);
    return SendServerMessage(m).then(response => {
        // response like 1, -1 is 'unknown'/'not set'
        return response;
    });
}
export function GetDLCWalletAccounting() {
    console.debug('GetDLCWalletAccounting()');
    const m = getMessageBody("getdlcwalletaccounting" /* getdlcwalletaccounting */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
// Do we want to support getting this back as a json payload?
export function BackupWallet(path) {
    console.debug('BackupWallet()', path);
    validateString(path, 'BackupWallet()', 'path');
    const m = getMessageBody("backupwallet" /* backupwallet */, [path]);
    return SendServerMessage(m).then(response => {
        // result: 'done'
        return response;
    });
}
/** Core Route Functions */
export function FinalizePSBT() {
    console.debug('FinalizePSBT()');
    const m = getMessageBody("finalizepsbt" /* finalizepsbt */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function ExtractFromPSBT() {
    console.debug('ExtractFromPSBT()');
    const m = getMessageBody("extractfrompsbt" /* extractfrompsbt */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function ConvertToPSBT() {
    console.debug('ConvertToPSBT()');
    const m = getMessageBody("converttopsbt" /* converttopsbt */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function CombinePSBT() {
    console.debug('CombinePSBT()');
    const m = getMessageBody("combinepsbts" /* combinepsbts */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function JoinPSBTs() {
    console.debug('JoinPSBTs()');
    const m = getMessageBody("joinpsbts" /* joinpsbts */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function DecodePSBT() {
    console.debug('DecodePSBT()');
    const m = getMessageBody("decodepsbt" /* decodepsbt */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function DecodeRawTransaction() {
    console.debug('DecodeRawTransaction()');
    const m = getMessageBody("decoderawtransaction" /* decoderawtransaction */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function AnalyzePSBT() {
    console.debug('AnalyzePSBT()');
    const m = getMessageBody("analyzepsbt" /* analyzepsbt */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function DecodeSign(signedHex) {
    console.debug('DecodeSign()', signedHex);
    validateString(signedHex, 'DecodeSign()', 'signedHex');
    const m = getMessageBody("decodesign" /* decodesign */, [signedHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function DecodeAccept(acceptHex) {
    console.debug('DecodeAccept()', acceptHex);
    validateString(acceptHex, 'DecodeAccept()', 'acceptHex');
    const m = getMessageBody("decodeaccept" /* decodeaccept */, [acceptHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function DecodeOffer(offerHex) {
    console.debug('DecodeOffer()', offerHex);
    validateString(offerHex, 'DecodeOffer()', 'offerHex');
    const m = getMessageBody("decodeoffer" /* decodeoffer */, [offerHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function DecodeContractInfo(contractInfoHex) {
    console.debug('DecodeContractInfo()', contractInfoHex);
    validateString(contractInfoHex, 'DecodeContractInfo()', 'contractInfoHex');
    const m = getMessageBody("decodecontractinfo" /* decodecontractinfo */, [contractInfoHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function DecodeAnnouncement(announcementHex) {
    console.debug('DecodeAnnouncement()', announcementHex);
    validateString(announcementHex, 'DecodeAnnouncement()', 'announcementHex');
    const m = getMessageBody("decodeannouncement" /* decodeannouncement */, [announcementHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
// 'failure' on error
export function DecodeAttestments(attestmentHex) {
    console.debug('DecodeAttestments()', attestmentHex);
    validateString(attestmentHex, 'DecodeAttestments()', 'attestmentHex');
    const m = getMessageBody("decodeattestments" /* decodeattestments */, [attestmentHex]);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function CreateMultiSig() {
    console.debug('CreateMultiSig()');
    const m = getMessageBody("createmultisig" /* createmultisig */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
/** Offers */
export function OfferList() {
    console.debug('OfferList()');
    const m = getMessageBody("offers-list" /* offerslist */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function OfferAdd(offerTLV, peer, message) {
    console.debug('OfferAdd()', peer, message);
    validateString(offerTLV, 'OfferAdd()', 'offerTLV');
    validateString(peer, 'OfferAdd()', 'peer');
    validateString(message, 'OfferAdd()', 'message');
    const m = getMessageBody("offer-add" /* offeradd */, [offerTLV, peer, message]);
    return SendServerMessage(m).then(response => {
        // Returns hash.hex
        return response;
    });
}
export function OfferRemove(hash) {
    console.debug('OfferRemove()', hash);
    validateString(hash, 'OfferRemove()', 'hash');
    const m = getMessageBody("offer-remove" /* offerremove */, [hash]);
    return SendServerMessage(m).then(response => {
        // Returns hash.hex
        return response;
    });
}
/** Contacts */
export function ContactList() {
    console.debug('ContactList()');
    const m = getMessageBody("contacts-list" /* contactslist */);
    return SendServerMessage(m).then(response => {
        return response;
    });
}
export function ContactAdd(alias, address, memo) {
    console.debug('ContactAdd()', alias, address, memo);
    validateString(alias, 'ContactAdd()', 'alias');
    validateString(address, 'ContactAdd()', 'address');
    validateString(memo, 'ContactAdd()', 'memo');
    const m = getMessageBody("contact-add" /* contactadd */, [alias, address, memo]);
    return SendServerMessage(m).then(response => {
        // Returns "ok"
        return response;
    });
}
export function ContactRemove(address) {
    console.debug('ContactRemove()', address);
    validateString(address, 'ContactRemove()', 'address');
    const m = getMessageBody("contact-remove" /* contactremove */, [address]);
    return SendServerMessage(m).then(response => {
        // Returns "ok"
        return response;
    });
}
export function DLCContactAdd(dlcId, address) {
    console.debug('DLCContactAdd()', dlcId, address);
    validateString(dlcId, 'DLCContactAdd()', 'dlcId');
    validateString(address, 'DLCContactAdd()', 'address');
    const m = getMessageBody("dlc-contact-add" /* dlccontactadd */, [dlcId, address]);
    return SendServerMessage(m).then(response => {
        // Returns "ok"
        return response;
    });
}
export function DLCContactRemove(dlcId) {
    console.debug('DLCContactRemove()', dlcId);
    validateString(dlcId, 'DLCContactRemove()', 'dlcId');
    const m = getMessageBody("dlc-contact-remove" /* dlccontactremove */, [dlcId]);
    return SendServerMessage(m).then(response => {
        // Returns "ok"
        return response;
    });
}
//# sourceMappingURL=index.js.map