export declare const enum CoreMessageType {
    finalizepsbt = "finalizepsbt",
    extractfrompsbt = "extractfrompsbt",
    converttopsbt = "converttopsbt",
    combinepsbts = "combinepsbts",
    joinpsbts = "joinpsbts",
    decodepsbt = "decodepsbt",
    decoderawtransaction = "decoderawtransaction",
    analyzepsbt = "analyzepsbt",
    decodesign = "decodesign",
    decodeaccept = "decodeaccept",
    decodeoffer = "decodeoffer",
    decodecontractinfo = "decodecontractinfo",
    decodeannouncement = "decodeannouncement",
    decodeattestments = "decodeattestments",
    createmultisig = "createmultisig",
    zipdatadir = "zipdatadir"
}
export interface Announcement {
    announcementSignature: string;
    publicKey: string;
    event: Event;
    hex: string;
}
export interface Event {
    eventId: string;
    descriptor: EnumEventDescriptor | NumericEventDescriptor;
    nonces: string[];
    maturity: string;
}
export interface EnumEventDescriptor {
    outcomes: string[];
}
export interface NumericEventDescriptor {
    base: number;
    isSigned: boolean;
    unit: string;
    precision: number;
}
export interface Attestment {
    eventId: string;
    signatures: string[];
    values: string[];
}
export interface Sign {
    cetAdaptorSignatures: {
        ecdsaAdaptorSignatures: {
            signature: string;
        }[];
    }[];
    contractId: string;
    fundingSignatures: {
        fundingSignatures: {
            witness: string;
        }[];
    };
    refundSignature: string;
}
export interface Accept {
    acceptCollateral: number;
    cetAdaptorSignatures: {
        ecdsaAdaptorSignatures: {
            signature: string;
        }[];
    }[];
    changeSerialId: string;
    changeSpk: string;
    fundingInputs: FundingInput[];
    fundingPubkey: string;
    negotiationFields: any;
    payoutSerialId: string;
    payoutSpk: string;
    refundSignature: string;
    temporaryContractId: string;
}
export interface Offer {
    contractFlags: string;
    chainHash: string;
    contractInfo: ContractInfo;
    fundingPubKey: string;
    payoutSPK: string;
    payoutSerialId: number;
    offerCollateral: number;
    fundingInputs: FundingInput[];
    changeSPK: string;
    changeSerialId: number;
    fundOutputSerialId: number;
    feeRatePerVb: number;
    cetLocktime: number;
    refundLocktime: number;
    temporaryContractId: string;
}
export interface ContractInfo {
    totalCollateral: number;
    contractDescriptor: EnumContractDescriptor | NumericContractDescriptor;
    oracleInfo: OracleInfo;
}
export interface FundingInput {
    inputSerialId: number;
    prevTx: string;
    prevTxVout: number;
    sequence: number;
    maxWitnessLen: number;
    redeemScript: string | null;
}
export interface ContractDescriptor {
    hex: string;
}
export interface EnumContractDescriptor extends ContractDescriptor {
    outcomes: {
        [key: string]: number;
    };
}
export interface NumericContractDescriptor extends ContractDescriptor {
    numDigits: number;
    payoutFunction: PayoutFunction;
    roundingIntervals: {
        intervals: unknown[];
    };
}
export interface PayoutFunction {
    points: PayoutFunctionPoint[];
}
export interface PayoutFunctionPoint {
    outcome: number;
    payout: number;
    extraPrecision: number;
    isEndpoint: boolean;
}
export interface OracleInfo {
    announcement: Announcement;
}
//# sourceMappingURL=core-types.d.ts.map